@@ -18,6 +18,7 @@ from fdsreader.utils import Mesh, Dimension, Surface, Quantity, Ventilation, Ext
 from fdsreader.utils.data import create_hash, get_smv_file, Device
 import fdsreader.utils.fortran_data as fdtype
 from fdsreader import settings
+from fdsreader._version import __version__
 
 
 class Simulation:
@@ -50,7 +51,7 @@ class Simulation:
             if os.path.isfile(pickle_file_path):
                 with open(pickle_file_path) as f:
                     sim = pickle.load(f)
-                if not isinstance(sim, cls):
+                if not isinstance(sim, cls) or sim.reader_version != __version__:
                     os.remove(pickle_file_path)
                 else:
                     if sim._hash == create_hash(smv_file_path):
@@ -66,14 +67,16 @@ class Simulation:
         """
         # Check if the file has already been instantiated via a cached pickle file
         if not hasattr(self, "_hash"):
+            self.reader_version = __version__
+
             self.smv_file_path = get_smv_file(path)
 
             self.root_path = os.path.dirname(self.smv_file_path)
 
             self.meshes: List[Mesh] = list()
             self.surfaces: List[Surface] = list()
-            self.obstructions: List[Obstruction] = list()
-            self.ventilations: List[Ventilation] = list()
+            self.obstructions: Dict[int, Obstruction] = dict()
+            self.ventilations: Dict[int, Ventilation] = dict()
 
             # First collect all meta-information for any FDS data to later combine the gathered
             # information into data collections
@@ -140,6 +143,8 @@ class Simulation:
 
             # POST INIT (post read)
             self.out_file_path = os.path.join(self.root_path, self.chid + ".out")
+            self.ventilations: List[Ventilation] = list(self.ventilations.values())
+            self.obstructions: List[Obstruction] = list(self.obstructions.values())
             for obst in self.obstructions:
                 obst._post_init()
             # Combine the gathered temporary information into data collections
@@ -287,9 +292,9 @@ class Simulation:
                 extent, vent_index, surface = temp_data[v]
             bound_indices, color_index, draw_type, rgba = read_common_info2()
             if vent_index not in self.ventilations:
-                self.ventilations.append(
-                    Ventilation(surface, bound_indices, color_index, draw_type, rgba=rgba,
-                                texture_origin=texture_origin))
+                self.ventilations[vent_index] = Ventilation(surface, bound_indices, color_index,
+                                                            draw_type, rgba=rgba,
+                                                            texture_origin=texture_origin)
             self.ventilations[vent_index]._add_subventilation(mesh, extent)
 
         smv_file.readline()
@@ -421,7 +426,7 @@ class Simulation:
             patch_infos = fdtype.read(infile, dtype_patches, n_patches)
             offset += fdtype.INT.itemsize + dtype_patches.itemsize * n_patches
             patch_offset = fdtype.FLOAT.itemsize
-            cell_centered = False
+            # cell_centered = False
             for patch_info in patch_infos:
                 patch_info = patch_info[0]
                 extent, dimension = self._indices_to_extent(patch_info[:6], mesh)
@@ -437,7 +442,7 @@ class Simulation:
                     if obst_id not in patches:
                         patches[obst_id] = list()
                     patches[obst_id].append(p)
-                patch_offset += fdtype.new((('f', str(p.shape)),)).itemsize
+                patch_offset += fdtype.new((('f', str(p.dimension.shape(cell_centered=False))),)).itemsize
 
         for obst_id, p in patches.items():
             for patch in p:
